@@ -1,7 +1,7 @@
 """Feature loaders for loading .csv from disk."""
+from __future__ import annotations
 
 from pathlib import Path
-from typing import Optional
 
 import pandas as pd
 
@@ -31,7 +31,7 @@ def load_split(
     feature_set_dir: Path,
     file_suffix: str,
     split: str,
-    nrows: Optional[int] = None,
+    nrows: int | None = None,
 ) -> pd.DataFrame:
     """Loads a given data split as a dataframe from a directory.
 
@@ -54,7 +54,7 @@ def load_split_predictors(
     file_suffix: str,
     split: str,
     include_id: bool,
-    nrows: Optional[int] = None,
+    nrows: int | None = None,
 ) -> pd.DataFrame:
     """Loads predictors from a given data split as a dataframe from a
     directory.
@@ -99,7 +99,7 @@ def load_split_outcomes(
     feature_set_dir: Path,
     file_suffix: str,
     split: str,
-    nrows: Optional[int] = None,
+    nrows: int | None = None,
 ) -> pd.DataFrame:
     """Loads outcomes from a given data split as a dataframe from a directory.
 
