@@ -1,16 +1,13 @@
 """Tests of coercion from strings to numerical."""
 
 import pandas as pd
-
 from psycop_feature_generation.loaders.non_numerical_coercer import (
     multiply_inequalities_in_df,
 )
 from psycop_feature_generation.utils_for_testing import (
-    str_to_df,  # pylint: disable=import-error
+    str_to_df,
 )
 
-# pylint: disable=missing-function-docstring
-
 
 def test_non_numerical_coercion():
     df_str = """dw_ek_borger,timestamp,value
